==> csm-linux-1.3.2.1-PREGA.i386.tar.gz: opt/csm/dcem/bin/dcemReport.pl <==
#!/usr/bin/perl

#=======================================================================
#
#
# Exit   - Exit with passed in Message and Return code
#
#
#=======================================================================

sub exit ()
{
  print "$1";
  exit (1); 

}

#=======================================================================
#
#
# Whoami - return the current user
#
#
#=======================================================================

sub Whoami()
{
  whoami

}


#=================================================================
#
#
# GetLang - Find out which language  
#
#=================================================================
sub GetLang ()
{

 if (( $LANG eq "C" ) || ( $LANG eq "" ))
 {
   $DEFAULT_LANG = ("en_US");
 }
 else
{
   $DEFAULT_LANG = ($LANG);
} 

}

#=======================================================================
#
#
# webServer Configured 
#
#
#=======================================================================

sub webServerConfigured ()
{

        
if  (($default_apache_docdir  ne "" ) && ( chdir ($default_apache_docdir) )) 
{
	print_message ("apache");	
}
	

if  ($DEFAULT_IHS_DOCDIR  ne "")  
{
if ( chdir ("$DEFAULT_IHS_DOCDIR$DEFAULT_LANG") ) 
	{
		print_message ("IHS");
	}
}

}


#=======================================================================
#
#
# linkReport - link report directory into documentation dir. 
# Link dcem report directory into apache and IHS documentation dir.
#
#=======================================================================

sub linkReport ()
{


	if  ($default_apache_docdir ne "")  
	{
		if  ( chdir ("$default_apache_docdir"))
		{ 
		$returnApache = `ln -sf $DEFAULT_DCEM_REPORT_DIR $default_apache_docdir/$DEFAULT_REPORT_DIRECTORY_LINK`;
		}
	}

	if  ($DEFAULT_IHS_DOCDIR ne "")
	{
 		 if ( chdir ("$DEFAULT_IHS_DOCDIR$DEFAULT_LANG")) 
		{
        	$returnIHS = `ln -sf $DEFAULT_DCEM_REPORT_DIR $DEFAULT_IHS_DOCDIR$DEFAULT_LANG/$DEFAULT_REPORT_DIRECTORY_LINK`;
		}
 	}
}


#=======================================================================
#
#
# unlinkReport - unlink the Reports DCEM
# Unlink the report for Documentation direcotry.
#
#
#=======================================================================

sub unlinkReport ()
{
	
	if  ($DEFAULT_IHS_DOCDIR ne "") 
	{
		if ( chdir ("$DEFAULT_IHS_DOCDIR/$DEFAULT_LANG")) 
		{
			exec ("rm -f $DEFAULT_IHS_DOCDIR/$DEFAULT_LANG/$DEFAULT_REPORT_DIRECTORY_LINK");
		}
        }	
	if  ($default_apache_docdir ne "") 
	{
		if ( chdir ($default_apache_docdir))
		{
			exec ("rm -f $default_apache_docdir/$DEFAULT_REPORT_DIRECTORY_LINK");
		}
	}
}



#=======================================================================
#
#
# discoverApacheDOC - discover the apache server by searching in 
# httpd.conf for DocumentRoot.   The value of DocumentRoot will
# be the directory of the documentation dir for apache webserver.
#
#=======================================================================

sub discoverApacheDOC ()
{

	local ($APACHE_DIR) = ("/etc/httpd/conf/httpd.conf");
	if (($APACHE_DIR ne "") && ( -e $APACHE_DIR ))  
	{
		$default_apache_docdir = `grep \'DocumentRoot [\"*\"]\' $APACHE_DIR | awk '{ print \$2 }' | tail -n 1`; 
		$default_apache_docdir =~ s/"/ /g;
		$default_apache_docdir =~ s/^\s+//;
		$default_apache_docdir =~ s/\s+$//;
		chomp ($default_apache_docdir);
	}
}

#========================================================================
#
# returnReportLink
#
#=======================================================================

sub returnReportLink ()
{
	print_message ($DEFAULT_REPORT_DIRECTORY_LINK);
}

#=========================================================================
#
# print_message - print to standard out the string message.
#
#
#=========================================================================

sub print_message ($)
{
	local ($str) = @_;
	print "$str\n";
}


#=========================================================================
#
# exit_return - Exit return  
#
#
#=========================================================================
sub exit_return ($)
{
	local ($exit_return) = @_;
	chomp ($exit_return);
	if ( $exit_return ne "0" )
	{
		exit (1);
	}
	else
	{
		exit (0);
	}
}


#=========================================================================
#
# launch netscape - launch browser.
#
#
#=========================================================================

sub launchBrowser ($)
{
	local ($str) = @_;
	$netscape = `ksh -c "whence netscape"`;
	chomp ($netscape);
	if ($netscape ne "" )
	{
		$browser = "$netscape -remote 'openURL($str, new-window)'";
		my (@resultsBrowser) = `$browser`;
		$rc = `echo $?`;
		chomp ($rc);
		if ( $rc eq "0" ) 
		{
		exit (0);
		}
		$browser = "$netscape $str";
		my (@resultsBrowser) = `$browser`;
		$rc = `echo $?`;
		exit_return ($rc);
	}
	$defaultbrowser = `ksh -c "whence defaultbrowser"`;
	chomp ($defaultbrowser);
	if ($defaultbrowser ne "" )
	{
		$browser =`$defaultbrowser $str new-window`;
		$rc = `echo $?`;
		exit_return ($rc);
	}
	print_message ("Try Again");
	$dtremotenscp = `ksh -c "whence dtremotenscp"`;
	chomp ($dtremotenscp);
	if ($dtremotenscp ne "" )
	{
		$browser = `$dtremotenscp $str new-window`;
		$rc = `echo $?`;
		exit_return ($rc);
	}
	exit (1);
}



#=========================================================================
#
#                     This is the MAIN of the reportLink script. 
#
#
#=========================================================================
#Set up Messages
my ($USAGE_MSG) = "dcemReport [ -webServer] [ -link report_directory] [ -unlink ] [ -reportLink ] [ -launchBrowser link] [ -help ] \n";


local ($DEFAULT_REPORT_DIRECTORY_LINK) = "dcem_reports";
local ($DEFAULT_IHS_DOCDIR) = "/usr/HTTPServer/htdocs/";

GetLang ();
discoverApacheDOC ();

if ( $ARGV [$0] eq "-link" )
{
	local ($DEFAULT_DCEM_REPORT_DIR) = $ARGV[1];
	linkReport ();
}

if ( $ARGV [$0] eq "-unlink" )
{
	unlinkReport ();
}

if ( $ARGV [$0] eq "-webServer" )
{
	webServerConfigured ();
}

if ( $ARGV [$0] eq "-reportLink" ) 
{
	returnReportLink ();
}

if ( $ARGV [$0] eq "-launchBrowser" )
{
	local ($url) = $ARGV[1];
	launchBrowser ($url);
}

if ( $ARGV [$0] eq "-help" )
{
	print_message ($USAGE_MSG);
}

exit (0);

==> csm-linux-1.3.2.2-14-PREGA.i386.tar.gz: opt/csm/dcem/bin/dcemReport.pl <==
#!/usr/bin/perl

#=======================================================================
#
#
# Exit   - Exit with passed in Message and Return code
#
#
#=======================================================================

sub exit ()
{
  print "$1";
  exit (1); 

}

#=======================================================================
#
#
# Whoami - return the current user
#
#
#=======================================================================

sub Whoami()
{
  whoami

}


#=================================================================
#
#
# GetLang - Find out which language  
#
#=================================================================
sub GetLang ()
{

 if (( $LANG eq "C" ) || ( $LANG eq "" ))
 {
   $DEFAULT_LANG = ("en_US");
 }
 else
{
   $DEFAULT_LANG = ($LANG);
} 

}

#=======================================================================
#
#
# webServer Configured 
#
#
#=======================================================================

sub webServerConfigured ()
{

        
if  (($default_apache_docdir  ne "" ) && ( chdir ($default_apache_docdir) )) 
{
	print_message ("apache");	
}
	

if  ($DEFAULT_IHS_DOCDIR  ne "")  
{
if ( chdir ("$DEFAULT_IHS_DOCDIR$DEFAULT_LANG") ) 
	{
		print_message ("IHS");
	}
}

}


#=======================================================================
#
#
# linkReport - link report directory into documentation dir. 
# Link dcem report directory into apache and IHS documentation dir.
#
#=======================================================================

sub linkReport ()
{


	if  ($default_apache_docdir ne "")  
	{
		if  ( chdir ("$default_apache_docdir"))
		{ 
		$returnApache = `ln -sf $DEFAULT_DCEM_REPORT_DIR $default_apache_docdir/$DEFAULT_REPORT_DIRECTORY_LINK`;
		}
	}

	if  ($DEFAULT_IHS_DOCDIR ne "")
	{
 		 if ( chdir ("$DEFAULT_IHS_DOCDIR$DEFAULT_LANG")) 
		{
        	$returnIHS = `ln -sf $DEFAULT_DCEM_REPORT_DIR $DEFAULT_IHS_DOCDIR$DEFAULT_LANG/$DEFAULT_REPORT_DIRECTORY_LINK`;
		}
 	}
}


#=======================================================================
#
#
# unlinkReport - unlink the Reports DCEM
# Unlink the report for Documentation direcotry.
#
#
#=======================================================================

sub unlinkReport ()
{
	
	if  ($DEFAULT_IHS_DOCDIR ne "") 
	{
		if ( chdir ("$DEFAULT_IHS_DOCDIR/$DEFAULT_LANG")) 
		{
			exec ("rm -f $DEFAULT_IHS_DOCDIR/$DEFAULT_LANG/$DEFAULT_REPORT_DIRECTORY_LINK");
		}
        }	
	if  ($default_apache_docdir ne "") 
	{
		if ( chdir ($default_apache_docdir))
		{
			exec ("rm -f $default_apache_docdir/$DEFAULT_REPORT_DIRECTORY_LINK");
		}
	}
}



#=======================================================================
#
#
# discoverApacheDOC - discover the apache server by searching in 
# httpd.conf for DocumentRoot.   The value of DocumentRoot will
# be the directory of the documentation dir for apache webserver.
#
#=======================================================================

sub discoverApacheDOC ()
{

	local ($APACHE_DIR) = ("/etc/httpd/conf/httpd.conf");
	if (($APACHE_DIR ne "") && ( -e $APACHE_DIR ))  
	{
		$default_apache_docdir = `grep \'DocumentRoot [\"*\"]\' $APACHE_DIR | awk '{ print \$2 }' | tail -n 1`; 
		$default_apache_docdir =~ s/"/ /g;
		$default_apache_docdir =~ s/^\s+//;
		$default_apache_docdir =~ s/\s+$//;
		chomp ($default_apache_docdir);
	}
}

#========================================================================
#
# returnReportLink
#
#=======================================================================

sub returnReportLink ()
{
	print_message ($DEFAULT_REPORT_DIRECTORY_LINK);
}

#=========================================================================
#
# print_message - print to standard out the string message.
#
#
#=========================================================================

sub print_message ($)
{
	local ($str) = @_;
	print "$str\n";
}


#=========================================================================
#
# exit_return - Exit return  
#
#
#=========================================================================
sub exit_return ($)
{
	local ($exit_return) = @_;
	chomp ($exit_return);
	if ( $exit_return ne "0" )
	{
		print_message( "First Exit" );
		exit (1);
	}
	else
	{
		print_message( "Second Exit" );
		exit (0);
	}
	print_message( "NONE" );
}


#=========================================================================
#
# launch netscape - launch browser.
#
#
#=========================================================================
sub launchBrowser ($)
{
	local ($str) = @_;
	$defaultbrowser = `ksh -c "whereis defaultbrowser" | awk '{ print \$2 }'`;
	chomp ($defaultbrowser);
	if ($defaultbrowser ne "" )
	{
		$browser =`$defaultbrowser $str new-window`;
		$rc = `echo $?`;
		chomp ($rc);
		if ( $rc eq "0" )
		{
			exit (0);
		}
	}
	
	$netscape = `ksh -c "whereis netscape" | awk '{ print \$2 }'`;
	chomp ($netscape);
	if ($netscape ne "" )
	{
		$browser = "$netscape -remote 'openURL($str, new-window)'";
		my (@resultsBrowser) = `$browser`;
		$rc = `echo $?`;
		chomp ($rc);
		if ( $rc eq "0" ) 
		{
			exit (0);
		}
		$browser = "$netscape $str";
		my (@resultsBrowser) = `$browser`;
		$rc = `echo $?`;
		chomp ($rc);
		if ( $rc eq "0" )
		{
			exit (0);
		}
	}
	$dtremotenscp = `ksh -c "whereis dtremotenscp" | awk '{ print \$2 }'`;
	chomp ($dtremotenscp);
	if ($dtremotenscp ne "" )
	{
		$browser = `$dtremotenscp $str new-window`;
		$rc = `echo $?`;
		chomp ($rc);
		if ( $rc eq "0" )
		{
			exit (0);
		}
	}
	$mozilla = `ksh -c "whereis mozilla" | awk '{ print \$2 }'`;
	chomp ($mozilla);
	if ($mozilla ne "" )
	{
		$browser = `$mozilla $str`;
		$rc = `echo $?`;
		chomp ($rc);
		if ($rc eq "0" )
		{
			exit (0);
		}
	}
	exit (1);
}



#=========================================================================
#
#                     This is the MAIN of the reportLink script. 
#
#
#=========================================================================
#Set up Messages
my ($USAGE_MSG) = "dcemReport [ -webServer] [ -link report_directory] [ -unlink ] [ -reportLink ] [ -launchBrowser link] [ -help ] \n";


local ($DEFAULT_REPORT_DIRECTORY_LINK) = "dcem_reports";
local ($DEFAULT_IHS_DOCDIR) = "/usr/HTTPServer/htdocs/";

$AIX		= "AIX";
$LINUX		= "Linux";

$OS	        = `/bin/uname -s`;

GetLang ();
discoverApacheDOC ();

if ( $ARGV [$0] eq "-link" )
{
	local ($DEFAULT_DCEM_REPORT_DIR) = $ARGV[1];
	linkReport ();
}

if ( $ARGV [$0] eq "-unlink" )
{
	unlinkReport ();
}

if ( $ARGV [$0] eq "-webServer" )
{
	webServerConfigured ();
}

if ( $ARGV [$0] eq "-reportLink" ) 
{
	returnReportLink ();
}

if ( $ARGV [$0] eq "-launchBrowser" )
{
	local ($url) = $ARGV[1];
	launchBrowser ($url);
}

if ( $ARGV [$0] eq "-help" )
{
	print_message ($USAGE_MSG);
}

exit (0);
